package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WorkerMoneyLogMapper;
import com.ruoyi.system.domain.WorkerMoneyLog;
import com.ruoyi.system.service.IWorkerMoneyLogService;

/**
 * 师傅金额明细Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class WorkerMoneyLogServiceImpl implements IWorkerMoneyLogService 
{
    @Autowired
    private WorkerMoneyLogMapper workerMoneyLogMapper;

    /**
     * 查询师傅金额明细
     * 
     * @param id 师傅金额明细主键
     * @return 师傅金额明细
     */
    @Override
    public WorkerMoneyLog selectWorkerMoneyLogById(Integer id)
    {
        return workerMoneyLogMapper.selectWorkerMoneyLogById(id);
    }

    /**
     * 查询师傅金额明细列表
     * 
     * @param workerMoneyLog 师傅金额明细
     * @return 师傅金额明细
     */
    @Override
    public List<WorkerMoneyLog> selectWorkerMoneyLogList(WorkerMoneyLog workerMoneyLog)
    {
        return workerMoneyLogMapper.selectWorkerMoneyLogList(workerMoneyLog);
    }

    /**
     * 新增师傅金额明细
     * 
     * @param workerMoneyLog 师傅金额明细
     * @return 结果
     */
    @Override
    public int insertWorkerMoneyLog(WorkerMoneyLog workerMoneyLog)
    {
        return workerMoneyLogMapper.insertWorkerMoneyLog(workerMoneyLog);
    }

    /**
     * 修改师傅金额明细
     * 
     * @param workerMoneyLog 师傅金额明细
     * @return 结果
     */
    @Override
    public int updateWorkerMoneyLog(WorkerMoneyLog workerMoneyLog)
    {
        return workerMoneyLogMapper.updateWorkerMoneyLog(workerMoneyLog);
    }

    /**
     * 批量删除师傅金额明细
     * 
     * @param ids 需要删除的师傅金额明细主键
     * @return 结果
     */
    @Override
    public int deleteWorkerMoneyLogByIds(Integer[] ids)
    {
        return workerMoneyLogMapper.deleteWorkerMoneyLogByIds(ids);
    }

    /**
     * 删除师傅金额明细信息
     * 
     * @param id 师傅金额明细主键
     * @return 结果
     */
    @Override
    public int deleteWorkerMoneyLogById(Integer id)
    {
        return workerMoneyLogMapper.deleteWorkerMoneyLogById(id);
    }
}
