package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.WorkerMoneyLog;
import com.ruoyi.system.service.IWorkerMoneyLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 师傅金额明细Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/workerMoneyLog")
public class WorkerMoneyLogController extends BaseController
{
    @Autowired
    private IWorkerMoneyLogService workerMoneyLogService;

    /**
     * 查询师傅金额明细列表
     */
    @PreAuthorize("@ss.hasPermi('system:workerMoneyLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(WorkerMoneyLog workerMoneyLog)
    {
        startPage();
        List<WorkerMoneyLog> list = workerMoneyLogService.selectWorkerMoneyLogList(workerMoneyLog);
        return getDataTable(list);
    }

    /**
     * 导出师傅金额明细列表
     */
    @PreAuthorize("@ss.hasPermi('system:workerMoneyLog:export')")
    @Log(title = "师傅金额明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkerMoneyLog workerMoneyLog)
    {
        List<WorkerMoneyLog> list = workerMoneyLogService.selectWorkerMoneyLogList(workerMoneyLog);
        ExcelUtil<WorkerMoneyLog> util = new ExcelUtil<WorkerMoneyLog>(WorkerMoneyLog.class);
        util.exportExcel(response, list, "师傅金额明细数据");
    }

    /**
     * 获取师傅金额明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:workerMoneyLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(workerMoneyLogService.selectWorkerMoneyLogById(id));
    }

    /**
     * 新增师傅金额明细
     */
    @PreAuthorize("@ss.hasPermi('system:workerMoneyLog:add')")
    @Log(title = "师傅金额明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkerMoneyLog workerMoneyLog)
    {
        return toAjax(workerMoneyLogService.insertWorkerMoneyLog(workerMoneyLog));
    }

    /**
     * 修改师傅金额明细
     */
    @PreAuthorize("@ss.hasPermi('system:workerMoneyLog:edit')")
    @Log(title = "师傅金额明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkerMoneyLog workerMoneyLog)
    {
        return toAjax(workerMoneyLogService.updateWorkerMoneyLog(workerMoneyLog));
    }

    /**
     * 删除师傅金额明细
     */
    @PreAuthorize("@ss.hasPermi('system:workerMoneyLog:remove')")
    @Log(title = "师傅金额明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(workerMoneyLogService.deleteWorkerMoneyLogByIds(ids));
    }
}
